@@ -5,7 +5,7 @@
 #    |_|_|_|_|_||_|_\__,_|_.__/
 #    simple python object store
 #
-# Copyright 2009-2010, 2014-2020 Thomas Perl <thp.io>. All rights reserved.
+# Copyright 2009-2010, 2014-2021 Thomas Perl <thp.io>. All rights reserved.
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -22,8 +22,21 @@
 
 """A simple SQLite3-based store for Python objects"""
 
+import sqlite3
+import threading
+import inspect
+import functools
+import types
+import collections
+import weakref
+import sys
+import json
+import datetime
+import logging
+
+
 __author__ = 'Thomas Perl <m@thp.io>'
-__version__ = '2.0.4'
+__version__ = '2.0.5'
 __url__ = 'http://thp.io/2010/minidb/'
 __license__ = 'ISC'
 
@@ -50,19 +63,6 @@ DEBUG_OBJECT_CACHE = False
 CONVERTERS = {}
 
 
-import sqlite3
-import threading
-import inspect
-import functools
-import types
-import collections
-import weakref
-import sys
-import json
-import datetime
-import logging
-
-
 logger = logging.getLogger(__name__)
 
 
@@ -106,7 +106,7 @@ class RowProxy(object):
         if isinstance(key, str):
             try:
                 index = self._keys.index(key)
-            except ValueError as ve:
+            except ValueError:
                 raise KeyError(key)
 
             return self._row[index]
